@@ -23,8 +23,6 @@
 #include <QString>
 #include <QColor>
 
-#include <boost/scoped_ptr.hpp>
-
 #include "RocsCoreExport.h"
 #include "CoreTypes.h"
 
@@ -140,6 +138,10 @@ public:
      */
     bool isPropertyVisible(const QString& name) const;
 
+    /**
+     * \return true if pointer type is visible, otherwise false.
+     */
+    bool isVisible() const;
 
 public slots:
     /**
@@ -163,6 +165,13 @@ public slots:
      */
     void setDirection(PointerType::Direction direction);
 
+    /**
+     * Set visibility for all pointers of this type.
+     *
+     * \param visibile is the new visibility value
+     */
+    void setVisible(bool visible);
+
     /**
      * Set line style for all pointers of this type.
      *
@@ -216,6 +225,11 @@ signals:
      */
     void propertyVisibilityChanged(const QString& name);
 
+    /**
+     * Emitted when the visibility was changed.
+     */
+    void visibilityChanged(bool visible);
+
     /**
      * Emitted when a property was renamed.
      */
@@ -232,7 +246,7 @@ protected:
     PointerType(Document* document, int identifier);
 
 private:
-    boost::scoped_ptr<PointerTypePrivate> d;
+    const QScopedPointer<PointerTypePrivate> d;
     PointerType(const PointerType &);
     PointerType & operator=(const PointerType &);
 };
